@@ -31,25 +31,34 @@ describe 'trove::api' do
 
       let :pre_condition do
         "class { 'trove':
-         nova_proxy_admin_pass      => 'verysecrete',
-         os_region_name             => 'RegionOne',
-         nova_compute_service_type  => 'compute',
-         cinder_service_type        => 'volume',
-         swift_service_type         => 'object-store',
-         neutron_service_type       => 'network',
-         glance_service_type        => 'image',
-         nova_compute_endpoint_type => '<SERVICE DEFAULT>',
-         cinder_endpoint_type       => '<SERVICE DEFAULT>',
-         swift_endpoint_type        => '<SERVICE DEFAULT>',
-         trove_endpoint_type        => '<SERVICE DEFAULT>',
-         glance_endpoint_type       => '<SERVICE DEFAULT>',
-         neutron_endpoint_type      => '<SERVICE DEFAULT>',
+           nova_compute_service_type  => 'compute',
+           cinder_service_type        => 'volume',
+           swift_service_type         => 'object-store',
+           neutron_service_type       => 'network',
+           glance_service_type        => 'image',
+           nova_compute_endpoint_type => '<SERVICE DEFAULT>',
+           cinder_endpoint_type       => '<SERVICE DEFAULT>',
+           swift_endpoint_type        => '<SERVICE DEFAULT>',
+           trove_endpoint_type        => '<SERVICE DEFAULT>',
+           glance_endpoint_type       => '<SERVICE DEFAULT>',
+           neutron_endpoint_type      => '<SERVICE DEFAULT>',
          }
-         class { '::trove::keystone::authtoken':
+         class { 'trove::api::service_credentials':
+           password => 'verysectrete',
+         }
+         class { 'trove::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
 
+      it 'includes required classes' do
+        is_expected.to contain_class('trove::deps')
+        is_expected.to contain_class('trove::db')
+        is_expected.to contain_class('trove::db::sync')
+        is_expected.to contain_class('trove::params')
+        is_expected.to contain_class('trove::api::service_credentials')
+      end
+
       it 'installs trove-api package and service' do
         is_expected.to contain_service('trove-api').with(
           :name      => platform_params[:api_service_name],
@@ -69,13 +78,8 @@ describe 'trove::api' do
         is_expected.to contain_trove_config('DEFAULT/bind_port').with_value('8779')
         is_expected.to contain_trove_config('DEFAULT/backlog').with_value('4096')
         is_expected.to contain_trove_config('DEFAULT/trove_api_workers').with_value('8')
-        is_expected.to contain_trove_config('DEFAULT/trove_auth_url').with_value('http://localhost:5000/v3')
-        is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_user').with_value('admin')
-        is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_pass').with_value('verysecrete')
-        is_expected.to contain_trove_config('DEFAULT/nova_proxy_admin_tenant_name').with_value('admin')
         is_expected.to contain_trove_config('DEFAULT/default_neutron_networks').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_config('DEFAULT/control_exchange').with_value('trove')
-        is_expected.to contain_trove_config('DEFAULT/os_region_name').with_value('RegionOne')
         is_expected.to contain_trove_config('DEFAULT/nova_compute_service_type').with_value('compute')
         is_expected.to contain_trove_config('DEFAULT/cinder_service_type').with_value('volume')
         is_expected.to contain_trove_config('DEFAULT/swift_service_type').with_value('object-store')
@@ -152,9 +156,12 @@ describe 'trove::api' do
       context 'with single tenant mode enabled' do
         let :pre_condition do
           "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             single_tenant_mode    => 'true'}
-           class { '::trove::keystone::authtoken':
+             single_tenant_mode => 'true'
+           }
+           class { 'trove::api::service_credentials':
+             password => 'verysecrete',
+           }
+           class { 'trove::keystone::authtoken':
              password => 'a_big_secret',
            }"
         end
@@ -167,10 +174,11 @@ describe 'trove::api' do
 
       context 'when using a single RabbitMQ server' do
         let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
+          "class { 'trove': }
+           class { 'trove::api::service_credentials':
+             password => 'verysecrete',
            }
-           class { '::trove::keystone::authtoken':
+           class { 'trove::keystone::authtoken':
              password => 'a_big_secret',
            }"
         end
@@ -183,13 +191,15 @@ describe 'trove::api' do
       context 'when using a single RabbitMQ server with enable ha options' do
         let :pre_condition do
           "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rabbit_ha_queues      => 'true',
-             amqp_durable_queues   => 'true',
+             rabbit_ha_queues    => 'true',
+             amqp_durable_queues => 'true',
            }
-            class { '::trove::keystone::authtoken':
-              password => 'a_big_secret',
-            }"
+           class { 'trove::api::service_credentials':
+             password => 'verysecrete',
+           }
+           class { 'trove::keystone::authtoken':
+             password => 'a_big_secret',
+           }"
         end
         it 'configures trove-api with RabbitMQ' do
           is_expected.to contain_trove_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
@@ -200,10 +210,12 @@ describe 'trove::api' do
       context 'when using multiple RabbitMQ servers' do
         let :pre_condition do
           "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rabbit_ha_queues      => 'true',
+             rabbit_ha_queues => 'true',
            }
-           class { '::trove::keystone::authtoken':
+           class { 'trove::api::service_credentials':
+             password => 'verysecrete',
+           }
+           class { 'trove::keystone::authtoken':
              password => 'a_big_secret',
            }"
         end
@@ -215,11 +227,13 @@ describe 'trove::api' do
       context 'when using Neutron' do
         let :pre_condition do
           "class { 'trove':
-             nova_proxy_admin_pass    => 'verysecrete',
              use_neutron              => true,
              default_neutron_networks => 'trove_service',
            }
-           class { '::trove::keystone::authtoken':
+           class { 'trove::api::service_credentials':
+             password => 'verysecrete',
+           }
+           class { 'trove::keystone::authtoken':
              password => 'a_big_secret',
            }"
         end
@@ -237,10 +251,12 @@ describe 'trove::api' do
       context 'when using Nova Network' do
         let :pre_condition do
           "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             use_neutron           => false
+             use_neutron => false
            }
-           class { '::trove::keystone::authtoken':
+           class { 'trove::api::service_credentials':
+             password => 'verysecrete',
+           }
+           class { 'trove::keystone::authtoken':
              password => 'a_big_secret',
            }"
         end
@@ -260,13 +276,16 @@ describe 'trove::api' do
     context 'with SSL enabled with kombu' do
       let :pre_condition do
         "class { 'trove':
-           nova_proxy_admin_pass => 'verysecrete',
            rabbit_use_ssl     => true,
            kombu_ssl_ca_certs => '/path/to/ssl/ca/certs',
            kombu_ssl_certfile => '/path/to/ssl/cert/file',
            kombu_ssl_keyfile  => '/path/to/ssl/keyfile',
-           kombu_ssl_version  => 'TLSv1'}
-         class { '::trove::keystone::authtoken':
+           kombu_ssl_version  => 'TLSv1'
+         }
+         class { 'trove::api::service_credentials':
+           password => 'verysecrete',
+         }
+         class { 'trove::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -285,9 +304,12 @@ describe 'trove::api' do
     context 'with SSL enabled without kombu' do
       let :pre_condition do
         "class { 'trove':
-           nova_proxy_admin_pass => 'verysecrete',
-           rabbit_use_ssl     => true}
-         class { '::trove::keystone::authtoken':
+           rabbit_use_ssl => true
+         }
+         class { 'trove::api::service_credentials':
+           password => 'verysecrete',
+         }
+         class { 'trove::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -306,9 +328,12 @@ describe 'trove::api' do
     context 'with SSL disabled' do
       let :pre_condition do
         "class { 'trove':
-           nova_proxy_admin_pass => 'verysecrete',
-           rabbit_use_ssl        => false}
-         class { '::trove::keystone::authtoken':
+           rabbit_use_ssl => false
+         }
+         class { 'trove::api::service_credentials':
+           password => 'verysecrete',
+         }
+         class { 'trove::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -327,12 +352,15 @@ describe 'trove::api' do
     context 'with transport_url entries' do
       let :pre_condition do
         "class { 'trove':
-           nova_proxy_admin_pass      => 'verysecrete',
            default_transport_url      => 'rabbit://rabbit_user:password@localhost:5673',
            rpc_response_timeout       => '120',
            control_exchange           => 'openstack',
-           notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673' }
-         class { '::trove::keystone::authtoken':
+           notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673'
+         }
+         class { 'trove::api::service_credentials':
+           password => 'verysecrete',
+         }
+         class { 'trove::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -347,10 +375,11 @@ describe 'trove::api' do
 
     context 'with amqp rpc' do
       let :pre_condition do
-        "class { 'trove' :
-           nova_proxy_admin_pass => 'verysecrete',
+        "class { 'trove': }
+         class { 'trove::api::service_credentials':
+           password => 'verysecrete',
          }
-         class { '::trove::keystone::authtoken':
+         class { 'trove::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
